@@ -895,6 +895,9 @@ class BundleSpec(HasTypeShapeTable):
     def to_dict(self) -> Dict:
         d = asdict(self)
         d["type_shape_table"] = {k.__name__: list(v) for k, v in d["type_shape_table"].items()}
+
+        meta_data_dict = {k: v for (k, v) in self.meta_data.items()}
+        d["meta_data"] = meta_data_dict
         return d
 
     @classmethod
@@ -902,6 +905,7 @@ class BundleSpec(HasTypeShapeTable):
         d["type_shape_table"] = {
             get_element_type(k): tuple(v) for k, v in d["type_shape_table"].items()
         }
+        d["meta_data"] = MetaData(d["meta_data"])
         return cls(**d)
 
     @classmethod
@@ -1105,17 +1109,19 @@ class EpisodeBundle(HasAList[EpisodeData], HasTypeShapeTable):
                 json.dump(self.metadata, f)
 
             tarfile = bundle_file_without_ext + ".tar"
-            tarfile_full = project_path / tarfile
-            if tarfile_full.exists():
+            tarfile_path = project_path / tarfile
+            if tarfile_path.exists():
                 if exist_ok:
-                    os.remove(tarfile_full)
+                    os.remove(tarfile_path)
                 else:
                     raise FileExistsError(
-                        "Bundle file already exists. remove the file or use exist_ok=True."
+                        "Bundle file {} already exists. remove this file or set exist_ok=True.".format(
+                            tarfile_path
+                        )
                     )
 
             # TODO: using python tarfile is clean appoach. If get annoyed, please send a PR
-            cmd = "cd {} && tar cvf {} *".format(tmp_dir_path, tarfile_full)
+            cmd = "cd {} && tar cvf {} *".format(tmp_dir_path, tarfile_path)
             subprocess.run(cmd, shell=True)
 
         # extra dump just for debugging (the following info is not requried to load bundle)
